console.time('Loading plugins');
var gulp = require('gulp');
var fs = require('fs');
var less = require('gulp-less');
var concat = require('gulp-concat');
var postcss = require('gulp-postcss');
var autoprefixer = require('autoprefixer');
var mqpacker = require("css-mqpacker");
var sorting = require("postcss-sorting");
var uglify = require("gulp-uglify");
var livereload = require('gulp-livereload');
var cssnano = require('cssnano');
var configPath = '../src/config.json';
var config = JSON.parse(fs.readFileSync(configPath));
var wpPot = require('gulp-wp-pot');
var watch = require("gulp-watch");
var lessImport = require('./less-imports.js');
var replace = require('gulp-replace');
console.timeEnd('Loading plugins');
gulp.task('less:dev', function() {
    less = less || require('gulp-less');
    postcss = postcss || require('gulp-postcss');
    autoprefixer = autoprefixer || require('autoprefixer');
    sorting = sorting || require("postcss-sorting");
    mqpacker = mqpacker || require("css-mqpacker");
    concat = concat || require('gulp-concat');
    livereload = livereload || require('gulp-livereload');
    return gulp.src("*.less", {
            cwd: "../src/less"
        })
        .pipe(lessImport('facebook-events.css', {
            excludeBanner: true
        }))
        .pipe(less())
        .pipe(postcss([autoprefixer({
                browsers: ['last 2 versions', 'ie 9', 'Android >= 4']
            }),
            sorting({
                "sort-order": "yandex",
                "empty-lines-between-media-rules": 1,
            }),
        ]))
        .pipe(gulp.dest("../css"))
        .pipe(livereload());
});
gulp.task('less:live', function() {
    return gulp.src("*.less", {
            cwd: "../src/less"
        })
        .pipe(lessImport('facebook-events.css', {
            excludeBanner: true
        }))
        .pipe(less())
        .pipe(postcss([autoprefixer({
                browsers: ['last 2 versions', 'ie 9', 'Android >= 4']
            }),
            mqpacker(),
            sorting({
                "sort-order": "yandex",
                "empty-lines-between-media-rules": 1,
            }),
            cssnano({
                discardComments: {
                    remove: function(comment) {
                        return comment[0] != "!";
                    }
                },
                discardOverridden: true,
                discardEmpty: true,
                mergeLonghand: true,
                colormin: true,
                zindex: false
            })
        ]))
        .pipe(gulp.dest("../css"));
});
gulp.task('js:editor', function() {
    var jsFiles = config.concat.js;
    return gulp.src("editor_plugin.js", {
            cwd: "../src/js"
        })
        .pipe(concat("editor_plugin.min.js"))
        .pipe(uglify({
            'compress': {},
            'sourceMap': false,
            'preserveComments': false
        }))
        .pipe(gulp.dest("../tinymce"));
});
gulp.task('js:dev', ['js:editor'], function() {
    var jsFiles = config.concat.js;
    return gulp.src(jsFiles, {
            cwd: "../src/js"
        })
        .pipe(concat("script.min.js"))
        .pipe(gulp.dest("../js"))
        .pipe(livereload());
});
gulp.task('js:live', ['js:editor'], function() {
    var jsFiles = config.concat.js;
    return gulp.src(jsFiles, {
            cwd: "../src/js"
        })
        .pipe(concat("script.min.js"))
        .pipe(uglify({
            'compress': {},
            'sourceMap': false,
            'preserveComments': false
        }))
        .pipe(gulp.dest("../js"));
});
gulp.task('pot', function() {
    var plugin = config.plugin;
    return gulp.src(["*.php", "*/*.php"], {
            cwd: "../"
        })
        .pipe(wpPot({
            domain: plugin.name,
            destFile: plugin.name + '.pot',
            package: plugin.name,
            bugReport: 'http://wppress.net',
            lastTranslator: 'Sovit Tamrakar <sovit.tamrakar@gmail.com>',
            team: 'Sovit Tamrakar <sovit.tamrakar@gmail.com>'
        }))
        .pipe(gulp.dest('../languages'));
});
gulp.task('plugin_version', function() {
    var plugin = config.plugin;
    gulp.src(plugin.file, {
            cwd: "../"
        })
        .pipe(replace(/(Plugin Name:\s?)(.*)/g, '$1' + plugin.title))
        .pipe(replace(/(Description:\s?)(.*)/g, '$1' + plugin.description))
        .pipe(replace(/(Plugin URI:\s?)(.*)/g, '$1' + plugin.pluginUrl))
        .pipe(replace(/(Author:\s?)(.*)/g, '$1' + plugin.author))
        .pipe(replace(/(Author URI:\s?)(.*)/g, '$1' + plugin.authorUrl))
        .pipe(replace(/(Text Domain:\s?)(.*)/g, '$1' + plugin.textdomain))
        .pipe(replace(/(Version:\s?)(.*)/g, '$1' + plugin.version))
        .pipe(gulp.dest("../"));
});
gulp.task('watch', function() {
    livereload.listen();
    gulp.watch("src/less/*.less", {
        cwd: '../'
    }, ['less:dev']);
    gulp.watch(["src/js/*.js"], {
        cwd: '../'
    }, ['js:dev']);
});
gulp.task('build:dev', ['less:dev', 'js:dev', 'pot', "plugin_version"]);
gulp.task('build:live', ['less:live', 'js:live', 'pot', "plugin_version"]);
gulp.task('default', ['build:dev', 'watch']);
gulp.task('deploy', ['build:live']);
gulp.task('live', ['deploy']);
